use bevy::audio::{AudioPlugin, SpatialScale};
use bevy::prelude::*;

mod assets;
mod camera;
mod movement;
mod player;
mod statue;

fn main() {
    let mut app = App::new();

    app.add_plugins(
        DefaultPlugins
            .set(WindowPlugin {
                primary_window: Some(Window {
                    title: "Kodo Tag".into(),
                    resolution: (800., 600.).into(),
                    ..Default::default()
                }),
                ..Default::default()
            })
            .set(AudioPlugin {
                spatial_scale: SpatialScale::new_2d(100.),
                ..default()
            })
            .set(ImagePlugin::default_nearest()),
    )
    .add_plugins((
        statue::Statue,
        camera::Camera,
        assets::AssetPlugin,
        player::Player,
        movement::Movement,
    ))
    .insert_resource(ClearColor(Color::rgb(0.3, 0., 0.5)))
    .insert_resource(AmbientLight {
        color: Color::rgb(1., 1., 1.),
        brightness: 1.,
    });

    app.run()
}
